emacs-commit
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-commit] Changes to emacs/lisp/term/x-win.el,v


From: Jan Djärv
Subject: [Emacs-commit] Changes to emacs/lisp/term/x-win.el,v
Date: Sat, 18 Nov 2006 13:16:44 +0000

CVSROOT:        /cvsroot/emacs
Module name:    emacs
Changes by:     Jan Djärv <jhd>        06/11/18 13:16:43

Index: x-win.el
===================================================================
RCS file: /cvsroot/emacs/emacs/lisp/term/x-win.el,v
retrieving revision 1.195
retrieving revision 1.196
diff -u -b -r1.195 -r1.196
--- x-win.el    10 Nov 2006 07:40:05 -0000      1.195
+++ x-win.el    18 Nov 2006 13:16:43 -0000      1.196
@@ -2334,20 +2334,17 @@
          (cond;; check cut buffer
           ((or (not cut-text) (string= cut-text ""))
            (setq x-last-selected-text-cut nil))
-          ;; This short cut doesn't work because x-get-cut-buffer
-          ;; always returns a newly created string.
-          ;; ((eq      cut-text x-last-selected-text-cut) nil)
-          ((string= cut-text x-last-selected-text-cut-encoded)
-           ;; See the comment above.  No need of this recording.
-           ;; Record the newer string,
-           ;; so subsequent calls can use the `eq' test.
-           ;; (setq x-last-selected-text-cut cut-text)
-           nil)
           (t
+           ;; We can not compare  x-last-selected-text-cut-encoded with
+           ;; cut-text because the next-selection-coding-system may have 
changed
+           ;; so we need to re-decode anyway.
            (setq x-last-selected-text-cut-encoded cut-text
                  x-last-selected-text-cut
-                 ;; ICCCM says cut buffer always contain ISO-Latin-1
-                 (decode-coding-string cut-text 'iso-latin-1)))))
+                 ;; ICCCM says cut buffer always contain ISO-Latin-1, but
+                 ;; use next-selection-coding-system if not nil.
+                 (decode-coding-string 
+                  cut-text 
+                  (or next-selection-coding-system 'iso-latin-1))))))
 
     ;; As we have done one selection, clear this now.
     (setq next-selection-coding-system nil)




reply via email to

[Prev in Thread] Current Thread [Next in Thread]